==> centreon-web-24.04.12.tar.gz: centreon-web-24.04.12/www/front_src/src/CloudNotificationsConfiguration/translatedLabels.ts <==
export const labelNotificationsManagement = 'Notification rules';
export const labelWelcomeToTheNotifications =
  'Welcome to the notifications interface';
export const labelCreateNotification = 'Create a notification rule';
export const labelAdd = 'Add';
export const labelDuplicate = 'Duplicate';
export const labelDelete = 'Delete';
export const labelDiscard = 'Discard';
export const labelCancel = 'Cancel';
export const labelName = 'Name';
export const labelChannels = 'Channels';
export const labelUsers = 'Users';
export const labelResources = 'Resources';
export const labelPeriod = 'Period';
export const labelActions = 'Actions';
export const labelStatus = 'Status';
export const labelSearch = 'Search';
export const labelSave = 'Save';
export const labelSelectResourcesAndEvents = 'Select resources and events';
export const labelSearchHostGroups = 'Search host groups';
export const labelSelectUsers = 'Select users';
export const labelNotificationSettings = 'Notification settings';
export const labelDeleteNotification = 'Delete notification rule?';
export const labelDeleteNotificationWarning = 'This action cannot be undone.';
export const labelReduceInformationPanel = 'Collapse information panel';
export const labelExpandInformationPanel = 'Expand information panel';
export const labelTypeYourTextHere = 'Type your text here';
export const labelActiveOrInactive = 'Active / Inactive';
export const labelChangeName = 'Edit name';
export const labelNotificationName = 'Notification name';
export const labelRequired = 'Required';
export const labelSuccessfulEditNotification =
  'The notification was successfully updated';
export const labelSuccessfulNotificationAdded =
  'The notification was successfully added';
export const labelConfirmAddNotification = 'Confirm notification creation';
export const labelChooseAtLeastOneResource = 'Choose at least 1 resource';
export const labelChooseAtleastOneServiceGroup =
  'Choose at least 1 service group';
export const labelChooseAtleastOneContact = 'Add at least 1 contact';
export const labelMessageFieldShouldNotBeEmpty =
  'The message field should not be empty!';
export const labelClosePanel = 'Close the panel';
export const labelEmailTemplateForTheNotificationMessage =
  'Email template for the notification message';
export const labelSubject = 'Subject';
export const labelNotificationChannels = 'Notification channels';
export const labelServiceGroups = 'Service groups';
export const labelHostGroups = 'Host groups';
export const labelTimePeriod = 'Time period';
export const labelSearchServiceGroups = 'Search service groups';
export const labelDoYouWantToQuitWithoutSaving =
  'Do you want to quit the form without saving the changes?';
export const labelYourFormHasUnsavedChanges = 'Your form has unsaved changes';
export const labelThisNameAlreadyExists = 'This name already exists';
export const labelCancelAddNotification = 'Cancel notification creation';
export const labelCancelEditNotification = 'Cancel notification update';
export const labelCreateNotificationForTheFirstTime =
  'Create notification for the first time';
export const labelNotificationSuccessfullyDeleted =
  'Notification deleted successfully';
export const labelNotificationsSuccessfullyDeleted =
  'The selected notifications have been deleted successfully';
export const labelFailedToDeleteNotification =
  'Failed to delete the notification';
export const labelFailedToDeleteNotifications =
  'Failed to delete the notifications';
export const labelFailedToDeleteSelectedNotifications =
  'Failed to delete the selected notifications';
export const labelDeleteMultipleNotifications = 'delete multiple notifications';
export const labelContacts = 'Contacts';
export const labelSearchContacts = 'Search contacts';
export const labelTimePeriod24h7days = '24h/24h - 7/7 days';
export const labelIncludeServicesForTheseHosts =
  'Include services for these hosts';
export const labelNotificationDuplicated = 'Notification duplicated';
export const labelFailedToDuplicateNotification =
  'Failed to duplicate the notification';
export const labelPleaseEnterNameForDuplicatedNotification =
  'Please enter a name for the duplicated notification';
export const labelTimePeridoTooltip =
  'Notifications will only be sent during this time period';
export const labelBusinessViews = 'Business Views';
export const labelSearchBusinessViews = 'Search Business Views';
export const labelBusinessViewsEvents = 'Business Views events';

==> centreon-web-24.11.0.tar.gz: centreon-web-24.11.0/www/front_src/src/CloudNotificationsConfiguration/translatedLabels.ts <==
export const labelNotificationsManagement = 'Notification rules';
export const labelWelcomeToTheNotifications =
  'Welcome to the notifications interface';
export const labelCreateNotification = 'Create a notification rule';
export const labelAdd = 'Add';
export const labelDuplicate = 'Duplicate';
export const labelDelete = 'Delete';
export const labelDiscard = 'Discard';
export const labelCancel = 'Cancel';
export const labelName = 'Name';
export const labelChannels = 'Channels';
export const labelUsers = 'Users';
export const labelResources = 'Resources';
export const labelPeriod = 'Period';
export const labelActions = 'Actions';
export const labelStatus = 'Status';
export const labelSearch = 'Search';
export const labelSave = 'Save';
export const labelSelectResourcesAndEvents = 'Select resources and events';
export const labelSearchHostGroups = 'Search host groups';
export const labelSelectUsers = 'Select users';
export const labelNotificationSettings = 'Notification settings';
export const labelDeleteNotification = 'Delete notification rule?';
export const labelDeleteNotificationWarning = 'This action cannot be undone.';
export const labelReduceInformationPanel = 'Collapse information panel';
export const labelExpandInformationPanel = 'Expand information panel';
export const labelTypeYourTextHere = 'Type your text here';
export const labelActiveOrInactive = 'Active / Inactive';
export const labelChangeName = 'Edit name';
export const labelNotificationName = 'Notification name';
export const labelRequired = 'Required';
export const labelSuccessfulEditNotification =
  'The notification was successfully updated';
export const labelSuccessfulNotificationAdded =
  'The notification was successfully added';
export const labelConfirmAddNotification = 'Confirm notification creation';
export const labelChooseAtLeastOneResource = 'Choose at least 1 resource';
export const labelChooseAtleastOneServiceGroup =
  'Choose at least 1 service group';
export const labelChooseAtleastOneContact = 'Add at least 1 contact';
export const labelMessageFieldShouldNotBeEmpty =
  'The message field should not be empty!';
export const labelClosePanel = 'Close the panel';
export const labelEmailTemplateForTheNotificationMessage =
  'Email template for the notification message';
export const labelSubject = 'Subject';
export const labelNotificationChannels = 'Notification channels';
export const labelServiceGroups = 'Service groups';
export const labelHostGroups = 'Host groups';
export const labelTimePeriod = 'Time period';
export const labelSelectTimePeriod = 'Select time period';
export const labelTimePeriodFieldShouldNotBeEmpty =
  'The time period field should not be empty!';
export const labelSearchServiceGroups = 'Search service groups';
export const labelDoYouWantToQuitWithoutSaving =
  'Do you want to quit the form without saving the changes?';
export const labelYourFormHasUnsavedChanges = 'Your form has unsaved changes';
export const labelThisNameAlreadyExists = 'This name already exists';
export const labelCancelAddNotification = 'Cancel notification creation';
export const labelCancelEditNotification = 'Cancel notification update';
export const labelCreateNotificationForTheFirstTime =
  'Create notification for the first time';
export const labelNotificationSuccessfullyDeleted =
  'Notification deleted successfully';
export const labelNotificationsSuccessfullyDeleted =
  'The selected notifications have been deleted successfully';
export const labelFailedToDeleteNotification =
  'Failed to delete the notification';
export const labelFailedToDeleteNotifications =
  'Failed to delete the notifications';
export const labelFailedToDeleteSelectedNotifications =
  'Failed to delete the selected notifications';
export const labelDeleteMultipleNotifications = 'delete multiple notifications';
export const labelContacts = 'Contacts';
export const labelSearchContacts = 'Search contacts';
export const labelTimePeriod24h7days = '24h/24h - 7/7 days';
export const labelIncludeServicesForTheseHosts =
  'Include services for these hosts';
export const labelNotificationDuplicated = 'Notification duplicated';
export const labelFailedToDuplicateNotification =
  'Failed to duplicate the notification';
export const labelPleaseEnterNameForDuplicatedNotification =
  'Please enter a name for the duplicated notification';
export const labelTimePeridoTooltip =
  'Notifications will only be sent during this time period';
export const labelBusinessViews = 'Business Views';
export const labelSearchBusinessViews = 'Search Business Views';
export const labelBusinessViewsEvents = 'Business Views events';
